#!/bin/csh

set COMP_DIR = ../out
set GNU_INP  = ./gnuplot.inp

mkdir -p ./zoom/tot
mkdir -p ./zoom/ela
mkdir -p ./zoom/rad

set NU_NAME = 1001.710nc

foreach CASE ( 000  001  002  003  004  005  006  007  008  009 )
  echo ${CASE}

#  set XMIN  = 1.0e-5
#  set XMIN  = 1.0e+5
  set XMIN   = 5.0e+6
  set XMAX   = 2.0e+7

  set FILE01 = ${COMP_DIR}/comp_result_${NU_NAME}_${CASE}1
  set FILE02 = ${COMP_DIR}/comp_result_${NU_NAME}_${CASE}2
  set FILE03 = ${COMP_DIR}/comp_result_${NU_NAME}_${CASE}3
  set FILE04 = ${COMP_DIR}/comp_result_${NU_NAME}_${CASE}4
  set FILE05 = ${COMP_DIR}/comp_result_${NU_NAME}_${CASE}5
  set FILE06 = ${COMP_DIR}/comp_result_${NU_NAME}_${CASE}6
  set FILE07 = ${COMP_DIR}/comp_result_${NU_NAME}_${CASE}7
  set FILE08 = ${COMP_DIR}/comp_result_${NU_NAME}_${CASE}8
  set FILE09 = ${COMP_DIR}/comp_result_${NU_NAME}_${CASE}9

  set FILE10 = ${COMP_DIR}/comp_result_${NU_NAME}_${CASE}0
  if( ${CASE} == "000" ) then
    set FILE10 = ${COMP_DIR}/comp_result_${NU_NAME}_0010
  else if( ${CASE} == "001" ) then
    set FILE10 = ${COMP_DIR}/comp_result_${NU_NAME}_0020
  else if( ${CASE} == "002" ) then
    set FILE10 = ${COMP_DIR}/comp_result_${NU_NAME}_0030
  else if( ${CASE} == "003" ) then
    set FILE10 = ${COMP_DIR}/comp_result_${NU_NAME}_0040
  else if( ${CASE} == "004" ) then
    set FILE10 = ${COMP_DIR}/comp_result_${NU_NAME}_0050
  else if( ${CASE} == "005" ) then
    set FILE10 = ${COMP_DIR}/comp_result_${NU_NAME}_0060
  else if( ${CASE} == "006" ) then
    set FILE10 = ${COMP_DIR}/comp_result_${NU_NAME}_0070
  else if( ${CASE} == "007" ) then
    set FILE10 = ${COMP_DIR}/comp_result_${NU_NAME}_0080
  else if( ${CASE} == "008" ) then
    set FILE10 = ${COMP_DIR}/comp_result_${NU_NAME}_0090
  else if( ${CASE} == "009" ) then
    set FILE10 = ${COMP_DIR}/comp_result_${NU_NAME}_0100
  endif

  foreach XS_TYPE( Total  Elastic  Radiation )
    set ENE       =   1
    set XS_R      =   2
    set XS_C      =   3

    set SUFFIX    = "0001.dat"
    set PNG_ONLY  = ./zoom/tot/${NU_NAME}_${CASE}_${XS_TYPE}.png
    if( ${XS_TYPE} == "Elastic" ) then
      set SUFFIX    = "0002.dat"
      set PNG_ONLY  = ./zoom/ela/${NU_NAME}_${CASE}_${XS_TYPE}.png
    else if( ${XS_TYPE} == "Radiation" ) then
      set SUFFIX    = "0102.dat"
      set PNG_ONLY  = ./zoom/rad/${NU_NAME}_${CASE}_${XS_TYPE}.png
    endif

    set FILE01_MOD = ${FILE01}_${SUFFIX}
    set FILE02_MOD = ${FILE02}_${SUFFIX}
    set FILE03_MOD = ${FILE03}_${SUFFIX}
    set FILE04_MOD = ${FILE04}_${SUFFIX}
    set FILE05_MOD = ${FILE05}_${SUFFIX}
    set FILE06_MOD = ${FILE06}_${SUFFIX}
    set FILE07_MOD = ${FILE07}_${SUFFIX}
    set FILE08_MOD = ${FILE08}_${SUFFIX}
    set FILE09_MOD = ${FILE09}_${SUFFIX}
    set FILE10_MOD = ${FILE10}_${SUFFIX}
  
    echo 'set xr ['${XMIN}':'${XMAX}']'                                              > ${GNU_INP}
#    echo 'set logscale y'                                                           >> ${GNU_INP}
#    echo 'set logscale x'                                                           >> ${GNU_INP}
    echo 'set format x  "%2.1e"'                                                    >> ${GNU_INP}
    echo 'set format y  "%2.1e"'                                                    >> ${GNU_INP}
    echo 'set xlabel  "Neutron Energy [eV]"'                                        >> ${GNU_INP}
    echo 'set ylabel  "Cross Section [barn]"'                                       >> ${GNU_INP}
    echo 'set border lw 6'                                                          >> ${GNU_INP}
    echo 'set title "'${NU_NAME}'-'${CASE}' ('${XS_TYPE}' Cross Section)"'          >> ${GNU_INP}
    echo 'set key left bottom'                                                      >> ${GNU_INP} 
    echo 'set key box lw 6'                                                         >> ${GNU_INP}
    echo 'set size ratio 0.46 1.0'                                                  >> ${GNU_INP}
    echo 'set terminal png size 3840, 2880'                                         >> ${GNU_INP}
    echo 'set terminal png font "/usr/share/fonts/liberation/LiberationSerif-Regular.ttf, 66"' >> ${GNU_INP}
    echo 'set out "'${PNG_ONLY}'"'                                                  >> ${GNU_INP}
    echo 'plot   "'${FILE01_MOD}'" using '${ENE}':'${XS_R}' w l lw 6 title " ORI"'  >> ${GNU_INP}
    echo 'set out "'${PNG_ONLY}'"'                                                  >> ${GNU_INP}
    echo 'replot "'${FILE01_MOD}'" using '${ENE}':'${XS_C}' w l lw 6 title " 01 "'  >> ${GNU_INP}
    echo 'set out "'${PNG_ONLY}'"'                                                  >> ${GNU_INP}
    echo 'replot "'${FILE02_MOD}'" using '${ENE}':'${XS_C}' w l lw 6 title " 02 "'  >> ${GNU_INP}
    echo 'set out "'${PNG_ONLY}'"'                                                  >> ${GNU_INP}
    echo 'replot "'${FILE03_MOD}'" using '${ENE}':'${XS_C}' w l lw 6 title " 03 "'  >> ${GNU_INP}
    echo 'set out "'${PNG_ONLY}'"'                                                  >> ${GNU_INP}
    echo 'replot "'${FILE04_MOD}'" using '${ENE}':'${XS_C}' w l lw 6 title " 04 "'  >> ${GNU_INP}
    echo 'set out "'${PNG_ONLY}'"'                                                  >> ${GNU_INP}
    echo 'replot "'${FILE05_MOD}'" using '${ENE}':'${XS_C}' w l lw 6 title " 05 "'  >> ${GNU_INP}
    echo 'set out "'${PNG_ONLY}'"'                                                  >> ${GNU_INP}
    echo 'replot "'${FILE06_MOD}'" using '${ENE}':'${XS_C}' w l lw 6 title " 06 "'  >> ${GNU_INP}
    echo 'set out "'${PNG_ONLY}'"'                                                  >> ${GNU_INP}
    echo 'replot "'${FILE07_MOD}'" using '${ENE}':'${XS_C}' w l lw 6 title " 07 "'  >> ${GNU_INP}
    echo 'set out "'${PNG_ONLY}'"'                                                  >> ${GNU_INP}
    echo 'replot "'${FILE08_MOD}'" using '${ENE}':'${XS_C}' w l lw 6 title " 08 "'  >> ${GNU_INP}
    echo 'set out "'${PNG_ONLY}'"'                                                  >> ${GNU_INP}
    echo 'replot "'${FILE09_MOD}'" using '${ENE}':'${XS_C}' w l lw 6 title " 09 "'  >> ${GNU_INP}
    echo 'set out "'${PNG_ONLY}'"'                                                  >> ${GNU_INP}
    echo 'replot "'${FILE10_MOD}'" using '${ENE}':'${XS_C}' w l lw 6 title " 10 "'  >> ${GNU_INP}
    gnuplot < ${GNU_INP}

    if( -z ${PNG_ONLY} ) then
      rm -rf ${PNG_ONLY}
    endif

    rm -rf ${GNU_INP}
  end
end

